@@ -47,13 +47,23 @@ from flytekit.models.literals import (
     LiteralCollection,
     LiteralMap,
     Primitive,
+    Record,
+    RecordField,
     Scalar,
     Schema,
     StructuredDatasetMetadata,
     Union,
     Void,
 )
-from flytekit.models.types import LiteralType, SimpleType, StructuredDatasetType, TypeStructure, UnionType
+from flytekit.models.types import (
+    LiteralType,
+    RecordFieldType,
+    RecordType,
+    SimpleType,
+    StructuredDatasetType,
+    TypeStructure,
+    UnionType,
+)
 
 T = typing.TypeVar("T")
 DEFINITIONS = "definitions"
@@ -142,10 +152,10 @@ def build_type_hack(type_, options, mixin, field, cls):
                     f"Nested dataclass field {field.name} of type "
                     f"{field.type} detected in "
                     f"{cls.__name__} that is not an instance of "
-                    f"dataclass_json. Did you mean to recursively "
-                    f"serialize this field? If so, make sure to "
+                    "dataclass_json. Did you mean to recursively "
+                    "serialize this field? If so, make sure to "
                     f"augment {type_} with either the "
-                    f"`dataclass_json` decorator or mixin."
+                    "`dataclass_json` decorator or mixin."
                 )
                 return mm_fields.Field(**options)
 
@@ -163,7 +173,7 @@ def build_type_hack(type_, options, mixin, field, cls):
 
         warnings.warn(
             f"Unknown type {type_} at {cls.__name__}.{field.name}: {field.type} "
-            f"It's advised to pass the correct marshmallow type to `mm_field`."
+            "It's advised to pass the correct marshmallow type to `mm_field`."
         )
         return mm_fields.Field(**options)
 
@@ -402,9 +412,12 @@ class DataclassTransformer(TypeTransformer[object]):
             )
 
         if not issubclass(t, DataClassJsonMixin):
-            raise AssertionError(
-                f"Dataclass {t} should be decorated with @dataclass_json to be " f"serialized correctly"
+            return LiteralType(
+                record_type=RecordType(
+                    [RecordFieldType(f.name, TypeEngine.to_literal_type(f.type)) for f in dataclasses.fields(t)]
+                )
             )
+
         schema = None
         try:
             s = cast(DataClassJsonMixin, t).schema()
@@ -476,17 +489,24 @@ class DataclassTransformer(TypeTransformer[object]):
         if not dataclasses.is_dataclass(python_val):
             raise TypeTransformerFailedError(
                 f"{type(python_val)} is not of type @dataclass, only Dataclasses are supported for "
-                f"user defined datatypes in Flytekit"
-            )
-        if not issubclass(type(python_val), DataClassJsonMixin):
-            raise TypeTransformerFailedError(
-                f"Dataclass {python_type} should be decorated with @dataclass_json to be " f"serialized correctly"
+                "user defined datatypes in Flytekit"
             )
+
         if not isinstance(python_val, python_type):
             raise TypeTransformerFailedError(
                 f"Cannot convert value of type {type(python_val)} to dataclass {python_type}"
             )
 
+        if not issubclass(type(python_val), DataClassJsonMixin):
+            fields = [
+                RecordField(
+                    f.name,
+                    TypeEngine.to_literal(ctx, getattr(python_val, f.name), f.type, TypeEngine.to_literal_type(f.type)),
+                )
+                for f in dataclasses.fields(python_type)
+            ]
+            return Literal(record=Record(fields=fields))
+
         schema = expected.metadata
         ref = schema["$ref"][len("#/definitions/") :]
         defs = schema["definitions"]
@@ -690,13 +710,35 @@ class DataclassTransformer(TypeTransformer[object]):
         if not dataclasses.is_dataclass(expected_python_type):
             raise TypeTransformerFailedError(
                 f"{expected_python_type} is not of type @dataclass, only Dataclasses are supported for "
-                f"user defined datatypes in Flytekit"
+                "user defined datatypes in Flytekit"
             )
         if not issubclass(expected_python_type, DataClassJsonMixin):
-            raise TypeTransformerFailedError(
-                f"Dataclass {expected_python_type} should be decorated with @dataclass_json to be "
-                f"serialized correctly"
-            )
+            if lv.record is None:
+                raise TypeTransformerFailedError(f"{lv} should be a record literal")
+
+            field_types = {}
+            for f in dataclasses.fields(expected_python_type):
+                field_types[f.name] = f.type
+
+            fields = {}
+            for f in lv.record.fields:
+                if f.key not in field_types:
+                    raise TypeTransformerFailedError(
+                        f"{lv} has extra field {f.key} for dataclass {expected_python_type}"
+                    )
+
+                fields[f.key] = TypeEngine.to_python_value(ctx, f.value, field_types[f.key])
+                del field_types[f.key]
+
+            if len(field_types) > 0:
+                raise TypeTransformerFailedError(
+                    f"{lv} has missing fields {', '.join(list(fields.keys()))} for dataclass {expected_python_type}"
+                )
+
+            try:
+                return expected_python_type(**fields)
+            except:
+                raise TypeTransformerFailedError(f"{lv} failed to convert to dataclass {expected_python_type}")
 
         data = _json_format.MessageToDict(lv.scalar.generic)
 
@@ -889,7 +931,8 @@ class TypeEngine(typing.Generic[T]):
                     continue
                 if data is not None:
                     raise ValueError(
-                        f"More than one FlyteAnnotation used within {python_type} typehint. Flytekit requires a max of one."
+                        f"More than one FlyteAnnotation used within {python_type} typehint. Flytekit requires a max of"
+                        " one."
                     )
                 data = x.data
         if data is not None:
@@ -934,6 +977,9 @@ class TypeEngine(typing.Generic[T]):
         """
         Converts a Literal value with an expected python type into a python value.
         """
+        if get_origin(expected_python_type) is Annotated:
+            expected_python_type = get_args(expected_python_type)[0]
+
         transformer = cls.get_transformer(expected_python_type)
         return transformer.to_python_value(ctx, lv, expected_python_type)
 
@@ -972,7 +1018,7 @@ class TypeEngine(typing.Generic[T]):
         """
         if len(lm.literals) != len(python_types):
             raise ValueError(
-                f"Received more input values {len(lm.literals)}" f" than allowed by the input spec {len(python_types)}"
+                f"Received more input values {len(lm.literals)} than allowed by the input spec {len(python_types)}"
             )
         return {k: TypeEngine.to_python_value(ctx, lm.literals[k], v) for k, v in python_types.items()}
 
@@ -1163,7 +1209,7 @@ def _are_types_castable(upstream: LiteralType, downstream: LiteralType) -> bool:
         if len(ucols) != len(dcols):
             return False
 
-        for (u, d) in zip(ucols, dcols):
+        for u, d in zip(ucols, dcols):
             if u.name != d.name:
                 return False
 
@@ -1335,9 +1381,8 @@ class DictTransformer(TypeTransformer[dict]):
         if _origin is not None:
             if _origin is Annotated:
                 raise ValueError(
-                    f"Flytekit does not currently have support \
-                        for FlyteAnnotations applied to dicts. {t} cannot be \
-                        parsed."
+                    "Flytekit does not currently have support                         for FlyteAnnotations applied to"
+                    f" dicts. {t} cannot be                         parsed."
                 )
             if _origin is dict and _args is not None:
                 return _args
@@ -1497,9 +1542,8 @@ class EnumTransformer(TypeTransformer[enum.Enum]):
     def get_literal_type(self, t: Type[T]) -> LiteralType:
         if get_origin(t) is Annotated:
             raise ValueError(
-                f"Flytekit does not currently have support \
-                    for FlyteAnnotations applied to enums. {t} cannot be \
-                    parsed."
+                "Flytekit does not currently have support                     for FlyteAnnotations applied to enums."
+                f" {t} cannot be                     parsed."
             )
 
         values = [v.value for v in t]  # type: ignore
